@@ -1,6 +1,6 @@
 <?php
 /*
-* Copyright (c) 2003-2011, CKSource - Frederico Knabben. All rights reserved.
+* Copyright (c) 2003-2013, CKSource - Frederico Knabben. All rights reserved.
 * For licensing, see LICENSE.html or http://ckeditor.com/license
 */
 
@@ -21,12 +21,12 @@ class CKEditor
 	 * The version of %CKEditor.
 	 * \private
 	 */
-	var $version = '3.6';
+	var $version = '3.6.6';
 	/**
 	 * A constant string unique for each release of %CKEditor.
 	 * \private
 	 */
-	var $_timestamp = 'B49E5BQ';
+	var $_timestamp = 'D03G5XL';
 
 	/**
 	 * URL to the %CKEditor installation directory (absolute or relative to document root).
@@ -80,7 +80,7 @@ class CKEditor
 	 * A string indicating the creation date of %CKEditor.
 	 * Do not change it unless you want to force browsers to not use previously cached version of %CKEditor.
 	 */
-	var $timestamp = "B49E5BQ";
+	var $timestamp = "D03G5XL";
 	/**
 	 * An array that holds event listeners.
 	 * \private
